==> jc-1.4.0.tar.gz: soot/jimple/parser/node/AMultBinop.h <==
// public final class soot.jimple.parser.node.AMultBinop

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4a0ff2b3ff399ba0 soot_jimple_parser_node_AMultBinop
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class b86441297795c006 soot_jimple_parser_node_PBinop

// header file dependencies
// @dep_header soot_jimple_parser_node_PBinop

#include "soot/jimple/parser/node/PBinop.h"

#ifndef _JC_soot_jimple_parser_node_AMultBinop_H_
#define _JC_soot_jimple_parser_node_AMultBinop_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TMult$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AMultBinop$sub_refs	_jc_soot_jimple_parser_node_AMultBinop$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AMultBinop$sub_nonrefs	_jc_soot_jimple_parser_node_AMultBinop$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AMultBinop$refs	_jc_soot_jimple_parser_node_AMultBinop$refs;
typedef struct _jc_soot_jimple_parser_node_AMultBinop$nonrefs	_jc_soot_jimple_parser_node_AMultBinop$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AMultBinop$object	_jc_soot_jimple_parser_node_AMultBinop$object;

typedef const struct _jc_soot_jimple_parser_node_AMultBinop$vmethods	_jc_soot_jimple_parser_node_AMultBinop$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AMultBinop$vtable	_jc_soot_jimple_parser_node_AMultBinop$vtable;
typedef const struct _jc_soot_jimple_parser_node_AMultBinop$vtype	_jc_soot_jimple_parser_node_AMultBinop$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AMultBinop$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AMultBinop$object *);
extern void _jc_soot_jimple_parser_node_AMultBinop$method$_init$e568d3974917f53d(_jc_env *, struct _jc_soot_jimple_parser_node_AMultBinop$object *, struct _jc_soot_jimple_parser_node_TMult$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_AMultBinop$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AMultBinop$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AMultBinop$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AMultBinop$object *);
extern struct _jc_soot_jimple_parser_node_TMult$object *_jc_soot_jimple_parser_node_AMultBinop$method$getMult$e9985566803f6c5c(_jc_env *, struct _jc_soot_jimple_parser_node_AMultBinop$object *);
extern void _jc_soot_jimple_parser_node_AMultBinop$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AMultBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AMultBinop$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AMultBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AMultBinop$method$setMult$0a4ddfe1850c0643(_jc_env *, struct _jc_soot_jimple_parser_node_AMultBinop$object *, struct _jc_soot_jimple_parser_node_TMult$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AMultBinop$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AMultBinop$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AMultBinop$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AMultBinop$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AMultBinop$method_info$getMult$e9985566803f6c5c;
extern _jc_method _jc_soot_jimple_parser_node_AMultBinop$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AMultBinop$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AMultBinop$method_info$setMult$0a4ddfe1850c0643;
extern _jc_method _jc_soot_jimple_parser_node_AMultBinop$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AMultBinop$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AMultBinop$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AMultBinop$object *);
	struct _jc_soot_jimple_parser_node_TMult$object	*(*getMult$e9985566803f6c5c)(_jc_env *, struct _jc_soot_jimple_parser_node_AMultBinop$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AMultBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AMultBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setMult$0a4ddfe1850c0643)(_jc_env *, struct _jc_soot_jimple_parser_node_AMultBinop$object *, struct _jc_soot_jimple_parser_node_TMult$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AMultBinop$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_AMultBinop$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBinop$vmethods	soot_jimple_parser_node_PBinop;
	_jc_soot_jimple_parser_node_AMultBinop$vmethods	soot_jimple_parser_node_AMultBinop;
};

// Vtype
struct _jc_soot_jimple_parser_node_AMultBinop$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AMultBinop$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AMultBinop$sub_refs {
	struct _jc_soot_jimple_parser_node_TMult$object	*__5fmult__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AMultBinop$refs {
    _jc_soot_jimple_parser_node_AMultBinop$sub_refs	soot_jimple_parser_node_AMultBinop;
    _jc_soot_jimple_parser_node_PBinop$sub_refs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AMultBinop$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AMultBinop$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBinop$sub_nonrefs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_AMultBinop$sub_nonrefs	soot_jimple_parser_node_AMultBinop;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AMultBinop$object {
	_jc_soot_jimple_parser_node_AMultBinop$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AMultBinop$vtype	*vtype;
	_jc_soot_jimple_parser_node_AMultBinop$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AMultBinop$vtype _jc_soot_jimple_parser_node_AMultBinop$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AMultBinop, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AMultBinop$class_object;

#endif	/* _JC_soot_jimple_parser_node_AMultBinop_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/AMultBinop.h <==
// public final class soot.jimple.parser.node.AMultBinop

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4a0ff2b3ff399ba0 soot_jimple_parser_node_AMultBinop
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class b86441297795c006 soot_jimple_parser_node_PBinop

// header file dependencies
// @dep_header soot_jimple_parser_node_PBinop

#include "soot/jimple/parser/node/PBinop.h"

#ifndef _JC_soot_jimple_parser_node_AMultBinop_H_
#define _JC_soot_jimple_parser_node_AMultBinop_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TMult$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AMultBinop$sub_refs	_jc_soot_jimple_parser_node_AMultBinop$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AMultBinop$sub_nonrefs	_jc_soot_jimple_parser_node_AMultBinop$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AMultBinop$refs	_jc_soot_jimple_parser_node_AMultBinop$refs;
typedef struct _jc_soot_jimple_parser_node_AMultBinop$nonrefs	_jc_soot_jimple_parser_node_AMultBinop$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AMultBinop$object	_jc_soot_jimple_parser_node_AMultBinop$object;

typedef const struct _jc_soot_jimple_parser_node_AMultBinop$vmethods	_jc_soot_jimple_parser_node_AMultBinop$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AMultBinop$vtable	_jc_soot_jimple_parser_node_AMultBinop$vtable;
typedef const struct _jc_soot_jimple_parser_node_AMultBinop$vtype	_jc_soot_jimple_parser_node_AMultBinop$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AMultBinop$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AMultBinop$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AMultBinop$method$_init$e568d3974917f53d(_jc_env *, struct _jc_soot_jimple_parser_node_AMultBinop$object *, struct _jc_soot_jimple_parser_node_TMult$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_AMultBinop$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AMultBinop$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AMultBinop$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AMultBinop$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TMult$object *_jc_soot_jimple_parser_node_AMultBinop$method$getMult$e9985566803f6c5c(_jc_env *, struct _jc_soot_jimple_parser_node_AMultBinop$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AMultBinop$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AMultBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AMultBinop$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AMultBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AMultBinop$method$setMult$0a4ddfe1850c0643(_jc_env *, struct _jc_soot_jimple_parser_node_AMultBinop$object *, struct _jc_soot_jimple_parser_node_TMult$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AMultBinop$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AMultBinop$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AMultBinop$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AMultBinop$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AMultBinop$method_info$getMult$e9985566803f6c5c;
extern _jc_method _jc_soot_jimple_parser_node_AMultBinop$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AMultBinop$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AMultBinop$method_info$setMult$0a4ddfe1850c0643;
extern _jc_method _jc_soot_jimple_parser_node_AMultBinop$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AMultBinop$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AMultBinop$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AMultBinop$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TMult$object	*(*getMult$e9985566803f6c5c)(_jc_env *, struct _jc_soot_jimple_parser_node_AMultBinop$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AMultBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AMultBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setMult$0a4ddfe1850c0643)(_jc_env *, struct _jc_soot_jimple_parser_node_AMultBinop$object *, struct _jc_soot_jimple_parser_node_TMult$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AMultBinop$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_AMultBinop$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBinop$vmethods	soot_jimple_parser_node_PBinop;
	_jc_soot_jimple_parser_node_AMultBinop$vmethods	soot_jimple_parser_node_AMultBinop;
};

// Vtype
struct _jc_soot_jimple_parser_node_AMultBinop$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AMultBinop$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AMultBinop$sub_refs {
	struct _jc_soot_jimple_parser_node_TMult$object	*__5fmult__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AMultBinop$refs {
    _jc_soot_jimple_parser_node_AMultBinop$sub_refs	soot_jimple_parser_node_AMultBinop;
    _jc_soot_jimple_parser_node_PBinop$sub_refs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AMultBinop$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AMultBinop$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBinop$sub_nonrefs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_AMultBinop$sub_nonrefs	soot_jimple_parser_node_AMultBinop;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AMultBinop$object {
	_jc_soot_jimple_parser_node_AMultBinop$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AMultBinop$vtype	*vtype;
	_jc_soot_jimple_parser_node_AMultBinop$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AMultBinop$vtype _jc_soot_jimple_parser_node_AMultBinop$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AMultBinop, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AMultBinop$class_object;

#endif	/* _JC_soot_jimple_parser_node_AMultBinop_H_ */
